Class: PaypalServerSdk::PhoneNumberWithCountryCode

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/paypal_server_sdk/models/phone_number_with_country_code.rb

Overview

The phone number in its canonical international E.164 numbering plan format., The phone number, in its canonical international E.164 numbering plan format., The phone number, in its canonical international E.164 numbering plan format.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(country_code:, national_number:) ⇒ PhoneNumberWithCountryCode

Returns a new instance of PhoneNumberWithCountryCode.



51
52
53
54
# File 'lib/paypal_server_sdk/models/phone_number_with_country_code.rb', line 51

def initialize(country_code:, national_number:)
  @country_code = country_code
  @national_number = national_number
end

Instance Attribute Details

#country_codeString

The country calling code (CC), in its canonical international E.164 numbering plan format. The combined length of the CC and the national number must not be greater than 15 digits. The national number consists of a national destination code (NDC) and subscriber number (SN).

Returns:

  • (String)


23
24
25
# File 'lib/paypal_server_sdk/models/phone_number_with_country_code.rb', line 23

def country_code
  @country_code
end

#national_numberString

The national number, in its canonical international E.164 numbering plan format. The combined length of the country calling code (CC) and the national number must not be greater than 15 digits. The national number consists of a national destination code (NDC) and subscriber number (SN).

Returns:

  • (String)


31
32
33
# File 'lib/paypal_server_sdk/models/phone_number_with_country_code.rb', line 31

def national_number
  @national_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/paypal_server_sdk/models/phone_number_with_country_code.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  country_code = hash.key?('country_code') ? hash['country_code'] : nil
  national_number =
    hash.key?('national_number') ? hash['national_number'] : nil

  # Create object from extracted values.
  PhoneNumberWithCountryCode.new(country_code: country_code,
                                 national_number: national_number)
end

.namesObject

A mapping from model property names to API property names.



34
35
36
37
38
39
# File 'lib/paypal_server_sdk/models/phone_number_with_country_code.rb', line 34

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['country_code'] = 'country_code'
  @_hash['national_number'] = 'national_number'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
# File 'lib/paypal_server_sdk/models/phone_number_with_country_code.rb', line 47

def self.nullables
  []
end

.optionalsObject

An array for optional fields



42
43
44
# File 'lib/paypal_server_sdk/models/phone_number_with_country_code.rb', line 42

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/paypal_server_sdk/models/phone_number_with_country_code.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} country_code: #{@country_code.inspect}, national_number:"\
  " #{@national_number.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
# File 'lib/paypal_server_sdk/models/phone_number_with_country_code.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} country_code: #{@country_code}, national_number: #{@national_number}>"
end